@@ -29,7 +29,7 @@ our @EXPORT = qw(
 	hash2vcard
 );
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 require XSLoader;
 XSLoader::load('Text::VCardFast', $VERSION);
@@ -112,6 +112,7 @@ sub vcardlines2hash_pp {
       die "END $1 in $Current->{type}"
         unless $Current->{type} eq lc $1;
       $Current = pop @Path;
+      return $Current if ($args->{only_one} and not @Path);
       next;
     }
 
@@ -402,6 +403,11 @@ Wikipedia:
 
   Options:
 
+  * only_one - A flag which, if true, means parsing will stop after
+    extracting a single VCard from the buffer.  This is very useful
+    in cases where, for example, a disclaimer has been added after
+    a calendar event in an email.
+
   * multival - A list of entry names which will be considered to have
     multiple values.  Instead of having a 'value' field in the hash,
     entries with this key will have a 'values' field containing an
